@@ -63,8 +63,8 @@ class ReadResponse(BaseModel):
         The READ  object
     """
     data: Optional[List[Record]]
-    watermark: Watermark
-    offsetType: OffsetType
+    watermark: Optional[Watermark]
+    offsetType: OffsetType = OffsetType.RECORD_COUNT
 
 class DescribeRequest(BaseModel):
     """
