@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from asyncio.log import logger
 import json
 from requests import Response
 from syncari.models.request import (DescribeRequest, ErrorResponse,
@@ -81,7 +82,13 @@ class Synapse(ABC):
                 json_vals.append(v.json())
             return json.dumps(json_vals)
 
-        return response.json()
+        try:
+            json_resp = response.json()
+            return json_resp
+        except:
+            logger.warn('Response was not serializable: {}'.format(response))
+            return response
+
         
     @property
     def name(self) -> str:
